[dpdk-stable] patch 'net/igb: fix PHY status if PHY reset is not blocked' has been queued to LTS release 18.11.6

Kevin Traynor ktraynor at redhat.com
Tue Dec 10 15:59:35 CET 2019


Hi,

FYI, your patch has been queued to LTS release 18.11.6

Note it hasn't been pushed to http://dpdk.org/browse/dpdk-stable yet.
It will be pushed if I get no objections before 12/16/19. So please
shout if anyone has objections.

Also note that after the patch there's a diff of the upstream commit vs the
patch applied to the branch. This will indicate if there was any rebasing
needed to apply to the stable branch. If there were code changes for rebasing
(ie: not only metadata diffs), please double check that the rebase was
correctly done.

Queued patches are on a temporary branch at:
https://github.com/kevintraynor/dpdk-stable-queue

This queued commit can be viewed at:
https://github.com/kevintraynor/dpdk-stable-queue/commit/c9a19b57badadef772195cd0afc51630998ae7dc

Thanks.

Kevin.

---
>From c9a19b57badadef772195cd0afc51630998ae7dc Mon Sep 17 00:00:00 2001
From: Shweta Choudaha <shweta.choudaha at att.com>
Date: Thu, 16 May 2019 23:03:31 +0100
Subject: [PATCH] net/igb: fix PHY status if PHY reset is not blocked

[ upstream commit 260dd6952600b5b44d0a1ce70a582116e6bd74fa ]

When PHY reset is blocked as is the case when BMC is connected via NC-SI
do not set GO_LINKD bit in PHY power management register in dev_stop as
this will disconnect the PHY. Also, in dev_close clear the GO_LINKD
bit only if PHY reset is not blocked

Fixes: 3af34dec0b41 ("igb: force phy power up/down")

Signed-off-by: Shweta Choudaha <shweta.choudaha at att.com>
Reviewed-by: Xiaolong Ye <xiaolong.ye at intel.com>
---
 drivers/net/e1000/igb_ethdev.c | 10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)

-- 
2.21.0

---
  Diff of the applied patch vs upstream commit (please double-check if non-empty:
---
--- -	2019-12-10 14:49:43.086003085 +0000
+++ 0061-net-igb-fix-PHY-status-if-PHY-reset-is-not-blocked.patch	2019-12-10 14:49:39.108456723 +0000
@@ -1 +1 @@
-From 260dd6952600b5b44d0a1ce70a582116e6bd74fa Mon Sep 17 00:00:00 2001
+From c9a19b57badadef772195cd0afc51630998ae7dc Mon Sep 17 00:00:00 2001
@@ -5,0 +6,2 @@
+[ upstream commit 260dd6952600b5b44d0a1ce70a582116e6bd74fa ]
+
@@ -12 +13,0 @@
-Cc: stable at dpdk.org
@@ -21 +22 @@
-index ce7c9e664..53e83d5ec 100644
+index 96ccf9763..23b48d161 100644
@@ -24 +25 @@
-@@ -1469,6 +1469,7 @@ eth_igb_stop(struct rte_eth_dev *dev)
+@@ -1515,6 +1515,7 @@ eth_igb_stop(struct rte_eth_dev *dev)
@@ -34 +35 @@
-@@ -1545,6 +1546,7 @@ eth_igb_close(struct rte_eth_dev *dev)
+@@ -1590,6 +1591,7 @@ eth_igb_close(struct rte_eth_dev *dev)



More information about the stable mailing list
diff --git a/drivers/net/e1000/igb_ethdev.c b/drivers/net/e1000/igb_ethdev.c
index 96ccf9763..23b48d161 100644
--- a/drivers/net/e1000/igb_ethdev.c
+++ b/drivers/net/e1000/igb_ethdev.c
@@ -1515,6 +1515,7 @@ eth_igb_stop(struct rte_eth_dev *dev)
 	E1000_WRITE_REG(hw, E1000_WUC, 0);
 
-	/* Set bit for Go Link disconnect */
-	if (hw->mac.type >= e1000_82580) {
+	/* Set bit for Go Link disconnect if PHY reset is not blocked */
+	if (hw->mac.type >= e1000_82580 &&
+	    (e1000_check_reset_block(hw) != E1000_BLK_PHY_RESET)) {
 		uint32_t phpm_reg;
 
@@ -1590,6 +1591,7 @@ eth_igb_close(struct rte_eth_dev *dev)
 	igb_hw_control_release(hw);
 
-	/* Clear bit for Go Link disconnect */
-	if (hw->mac.type >= e1000_82580) {
+	/* Clear bit for Go Link disconnect if PHY reset is not blocked */
+	if (hw->mac.type >= e1000_82580 &&
+	    (e1000_check_reset_block(hw) != E1000_BLK_PHY_RESET)) {
 		uint32_t phpm_reg;
 